make_split_dataframe

Function make_split_dataframe 

pub fn make_split_dataframe<K>(
    separator: Option<&str>,
    col_names: Vec<K>,
) -> Fallible<Transformation<AtomDomain<String>, SymmetricDistance, DataFrameDomain<K>, SymmetricDistance>>
where K: Hashable,
👎Deprecated since 0.12.0:

Use Polars instead.

Make a Transformation that splits each record in a String into a Vec<Vec<String>>, and loads the resulting table into a dataframe keyed by col_names.

Arguments

  • separator - The token(s) that separate entries in each record.
  • col_names - Column names for each record entry.

Generics

  • K - categorical/hashable data type of column names